@@ -90,7 +90,7 @@ from types import GeneratorType, ModuleType, FunctionType, BuiltinFunctionType
 from collections import deque
 from binascii import a2b_hex, b2a_hex
 
-VERSION = '0.19.1'
+VERSION = '0.20'
 MIN_SERVER_VERSION = '0.09'
 
 PYTHON3 = sys.version_info >= (3, 0)
@@ -2057,6 +2057,105 @@ def parse_connection_spec(spec, default_port=DEFAULT_PORT, default_key=b'',
     else:
         return params
 
+def _get_global_root(mod, attr):
+    try:
+        return getattr(mod, attr)
+    except AttributeError:
+        return getattr(builtins, attr)
+
+def _try_import(mod, name, is_root):
+    newname = (name if is_root else mod.__name__ + '.' + name)
+    try:
+        newmod = __import__(newname)
+    except ImportError:
+        return None
+
+    if is_root:
+        if mod is not builtins:
+            setattr(mod, name, newmod)
+        val = newmod
+    else:
+        val = getattr(mod, name)
+
+    return val
+
+def get_global(name, context=None, auto_import=False):
+    """
+    Get a global variable in the context of the given module. If C{name} contains
+    periods, it will call getattr() to resolve the actual value of the
+    object.
+
+    @type  name: str
+    @param name: The absolute or relative name of the global to get.
+
+    @type  context: ModuleType
+    @param context: The module that the name should be resolved against. If not
+    specified, the name must either be absolute, or the name of a built-in
+    function or type.
+
+    @type  auto_import: bool
+    @param auto_import: If and accessing a value from a module fails, the module
+    will be imported. If a C{context} module is specified, the resulting
+    imported module will be exposed to that module. For example, if C{testmod}
+    is a module, then running C{get_global('os.path.join', testmod, True)} will
+    set C{os} in C{testmod} just as if testmod contained C{import os.path}.
+
+    @rtype:  object
+    @return: The value of the global variable.
+    """
+
+    components = name.split('.')
+    if context is None:
+        val = builtins
+        _getattr = getattr
+    else:
+        val = context
+        _getattr = _get_global_root
+
+    for i, name in enumerate(components):
+        try:
+            val = _getattr(val, name)
+        except AttributeError:
+            if auto_import and isinstance(val, ModuleType):
+                val = _try_import(val, name, i == 0)
+                if val is None:
+                    raise
+            else:
+                raise
+        _getattr = getattr
+
+    return val
+
+def set_global(name, value, context=None):
+    """ 
+    Set a global variable in the context of the given module. If C{name}
+    contains periods, it will call getattr() to resolve the actual value of the
+    object on which to set the attribute.
+
+    @type  name: str
+    @param name: The absolute or relative name of the global to set.
+
+    @type  value: object
+    @param value: The value to put in the global.
+
+    @type  context: ModuleType
+    @param context: The module
+    If `auto_import` is true, and accessing a value from a module fails, it will
+    attempt to import the module and retry the access.
+    """
+
+    components = name.split('.')
+    if context is None:
+        context = builtins
+
+    if len(components) == 1:
+        if context is builtins:
+            raise TypeError('Cannot set non-absolute global without context module')
+        setattr(context, name, value)
+    else:
+        gv = get_global('.'.join(components[:-1]), context)
+        setattr(gv, components[-1], value)
+
 ###############################
 # Internal classes
 ###############################
