@@ -91,66 +91,7 @@ except ImportError:
                 return socka, sockb
             sockb.close()
 
-def _get_global_root(mod, attr):
-    try:
-        return getattr(mod, attr)
-    except AttributeError:
-        return getattr(_core.builtins, attr)
-
-def _try_import(mod, name, is_root):
-    newname = (name if is_root else mod.__name__ + '.' + name)
-    try:
-        newmod = __import__(newname)
-    except ImportError:
-        return False
-
-    if is_root:
-        setattr(mod, name, newmod)
-
-    return True
-
-def _get_global(name, defmod, auto_import=False):
-    """
-    Get a global variable in the context of `defmod`. If `name` contains
-    periods, it will call getattr() to resolve the actual value of the object.
-
-    If `auto_import` is true, and accessing a value from a module fails, it will
-    attempt to import the module and retry the access.
-
-    """
-
-    components = name.split('.')
-    _getattr = _get_global_root
-    val = defmod
-
-    for i, name in enumerate(components):
-        try:
-            val = _getattr(val, name)
-        except AttributeError:
-            if auto_import and isinstance(val, ModuleType) and _try_import(val, name, i == 0):
-                val = _getattr(val, name)
-            else:
-                raise
-        _getattr = getattr
-
-    return val
-
-def _set_global(name, defmod, value):
-    """
-    Set a global variable in the context of `defmod`. If `name` contains
-    periods, it will call getattr() to resolve the actual object on which to set
-    the attribute.
-
-    """
-
-    components = name.split('.')
-    if len(components) == 1:
-        setattr(defmod, name, value)
-    else:
-        gv = _get_global('.'.join(components[:-1]), defmod)
-        setattr(gv, components[-1], value)
-
-_method_types = BuiltinMethodType, MethodType, FunctionType, type(_set_global.__call__)
+_method_types = BuiltinMethodType, MethodType, FunctionType, type(_core.set_global.__call__)
 
 class RootObject(object):
     '''Utility class instantiated automatically on the server as OID 0.'''
@@ -165,17 +106,17 @@ class RootObject(object):
             return e.val
         
     def get_global(self, name):
-        return _get_global(name, self._defmod, True)
+        return _core.get_global(name, self._defmod, True)
 
     def set_global(self, name, value):
-        return _set_global(name, self._defmod, value)
+        return _core.set_global(name, value, self._defmod)
 
     def update_definitions(self, code):
         for c in code:
             self._defmod.define(c)
 
     def call(self, func, args, kwargs={}):
-        f = _get_global(func, self._defmod, True)
+        f = _core.get_global(func, self._defmod, True)
         return f(*args, **kwargs)
         
     def getattr(self, obj, attr):
@@ -688,7 +629,7 @@ def run_server(port, key, bindaddr=None, allow=(),
     except socket.error as e:
         # "An address incompatible with the requested protocol was used"
         # - means IPv6 is not supported
-        if x.args == 10047:
+        if e.args[0] == 10047:
             family = socket.AF_INET
             sock = socket.socket(family, socket.SOCK_STREAM)
         else:
